@@ -1,6 +1,18 @@
 <?php
 
 
+   // change this to TRUE to disable plugin config test functionality
+   // which will increase performance (minimally)
+   //
+   $disable_config_check = FALSE;
+
+
+
+
+   global $compatibility_sm_path, $compatibility_disable_config_check;
+   $compatibility_disable_config_check = $disable_config_check;
+
+
    // Some uses of this plugin (such as vlogin) were somehow calling the
    // functions here before having included the functions in global.php,
    // resulting in fatal errors when called below.  Thus, the need for
@@ -32,6 +44,9 @@
       else if (file_exists(SM_PATH . 'src/global.php'))
          include_once(SM_PATH . 'src/global.php');
 
+
+      $compatibility_sm_path = SM_PATH;
+
    }
    else
    {
@@ -39,6 +54,8 @@
 
       if (file_exists('../src/global.php'))
          include_once('../src/global.php');
+
+      $compatibility_sm_path = '../';
    }
 
 
@@ -215,4 +232,51 @@
        }
    }
 
+
+   // checks a plugin to see if the user has installed it 
+   // correctly by checking for the existence of the given
+   // files (all relative from the plugin's directory)
+   //
+   // $pluginName should be the name of the plugin as it is
+   // known to SquirrelMail, that is, it is the name of the
+   // plugin directory
+   //
+   // $configFiles should be an array of any files that the
+   // user should have set up for this plugin, for example:
+   // array('config.php') or array('data/config.php', 'data/admins.php')
+   // where all files will be referenced from the plugin's
+   // main directory
+   //
+   function compatibility_check_plugin_setup($pluginName, $configFiles)
+   {
+
+      global $compatibility_disable_config_check;
+      if ($compatibility_disable_config_check) return;
+
+
+      global $compatibility_sm_path;
+
+
+      // check one at a time...
+      //
+      foreach ($configFiles as $configFile)
+      {
+
+         if (!file_exists($compatibility_sm_path . 'plugins/' . $pluginName . '/' . $configFile))
+         {
+
+            global $color;
+            plain_error_message(_("Administrative error:") . '<br />' 
+               . _("The plugin") . ' "<b>' . $pluginName 
+               . '</b>" ' . _("has not been set up correctly.") . '<br />' 
+               . _("Missing ") . '<b>' . $configFile . '</b><br />' 
+               . _("Please read the README or INSTALL files that came with the plugin."), $color);
+            exit;
+
+         }
+
+      }
+
+   }
+
 ?>
